docx\_parser\_converter.docx\_parsers.document.margins\_parser module
=====================================================================

.. automodule:: docx_parser_converter.docx_parsers.document.margins_parser
   :members:
   :undoc-members:
   :show-inheritance:
